@@ -18,7 +18,7 @@ class BobsledClient:
         self.s.headers.update(headers)
         
         params = {
-            "_data": "routes/__unauth/[signin-with-password]"
+            "_data": "routes/__unauth/signin-with-password"
         }
         
         r = self.s.post(
@@ -217,9 +217,6 @@ class BobsledClient:
             if r.status_code != 200:
                 handle_errors(r)
             json_locations = r.json()['locations']
-            # locations_list_ids = []
-            # for location in json_locations:
-            #     locations_list_ids.append(location['id'])
             return json_locations
 
         def set_source_location(self, location_id):
@@ -282,10 +279,11 @@ class BobsledClient:
             if r.status_code != 204:
                 handle_errors(r)
 
-        def get_all_files(self):
-            """Returns flattened contents of all files in source location
+        def get_all_files(self, time=0):
+            """Returns flattened contents of all files that were last modified after time in source location
 
             :calls: `GET /shares/{share_id}/loadCloudData`
+            :param time: UNIX timestamp in seconds
             :return: list of file paths
             """            
             params = {
@@ -301,7 +299,7 @@ class BobsledClient:
             
             prefix = self.get_share_information()["share"]["sourceLocation"]["url"]
             
-            return flatten(folderContents, prefix)
+            return flatten(folderContents, prefix, time)
         
         def get_source_contents(self):
             """Returns folder structure of source location and prefix
@@ -324,21 +322,17 @@ class BobsledClient:
             
             return prefix, folderContents
 
-        # NEED TO CHANGE THIS
         def get_deliveries(self):
             """Returns the list of deliveries of this share
 
-            :calls: `GET /shares/{share_id}/driver`
+            :calls: `GET /shares/{share_id}`
             :return: list of deliveries
             """            
-            r = self.s.get(self.base_url + "/shares/" + self.share_id +
-                "/driver")
-            delivery_list = []
-            for obj in r.json():
-                delivery_list.append(self.Delivery(obj["id"], self.share_id, self.s, self.base_url))
-            return delivery_list
+            
+            share_info = self.get_share_information()
+            return share_info["deliveries"]
 
-        def create_delivery(self, selection):
+        def create_delivery(self, selection, size = 1000):
             """Creates and returns a Delivery object given selection of file paths
 
             :calls: `POST /shares/{share_id}/delivery`
@@ -346,14 +340,20 @@ class BobsledClient:
             """            
 
             data = {
-                "sharedFiles": selection.__str__().replace(" ", "").replace(
-                    "\'", "\""),  # we have to fit specific format
-                "totalSize": "1000" # placeholder
+                "sharedFiles": selection.__str__().replace("\', \'", "\',\'").replace(
+                    "\'", "\""),# .replace(" ", "+"),  # we have to fit specific format
+                "totalSize": size # placeholder
             }
+            
+            # params = {
+            #     "_data": "routes/__auth/shares.$shareId/delivery"
+            # }
+            
             r = self.s.post(
                 self.base_url + "/shares/" + self.share_id +
                 "/delivery",
                 data=data,
+            #    params=params,
                 allow_redirects=False)
             
             if r.status_code != 302:
@@ -499,7 +499,8 @@ class BobsledClient:
                 :calls: `POST /shares/{share_id}`
                 """                
                 data = {
-                    "deliverDeliveryId": self.delivery_id
+                    "deliverDeliveryId": self.delivery_id,
+                    "actionType": "deliverDelivery"
                 }
                 params = {
                     "_data": "routes/__auth/shares.$shareId"
@@ -511,7 +512,6 @@ class BobsledClient:
                 if not (200 <= r.status_code < 300):
                     handle_errors(r)
             
-            # This is really inefficient right now, is there a better way to do this?
             def status(self):
                 """Returns the current status of the delivery
 
@@ -523,8 +523,6 @@ class BobsledClient:
                         return delivery["state"]
                 return "invalid"
                 
-                    
-            # might have to change params for $deliveryId?
             def access(self):
                 """Returns the URL to access this delivery
 
